# Section

The Section commands are used to create sections and profiles with their associated properties and behavior. The various section objects are all derived from the Section object. The various profile objects are all derived from the Profile object. See Property commands for the property assignment commands.

```{toctree}
:caption: Objects in Section
:maxdepth: 1

section/connector
```

## Create sections

### In Mdb

```{eval-rst}
.. autoclass:: abaqus.Section.SectionModel.SectionModel
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

### In Odb

```{eval-rst}
.. autoclass:: abaqus.Section.SectionOdb.SectionOdb
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

## Classes

### Section

```{eval-rst}
.. autoclass:: abaqus.Section.Section.Section
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SectionBase

```{eval-rst}
.. autoclass:: abaqus.Section.SectionBase.SectionBase
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### AcousticInfiniteSection

```{eval-rst}
.. autoclass:: abaqus.Section.AcousticInfiniteSection.AcousticInfiniteSection
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### AcousticInterfaceSection

```{eval-rst}
.. autoclass:: abaqus.Section.AcousticInterfaceSection.AcousticInterfaceSection
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### BeamSection

```{eval-rst}
.. autoclass:: abaqus.Section.BeamSection.BeamSection
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### CohesiveSection

```{eval-rst}
.. autoclass:: abaqus.Section.CohesiveSection.CohesiveSection
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### CompositeShellSection

```{eval-rst}
.. autoclass:: abaqus.Section.CompositeShellSection.CompositeShellSection
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### CompositeSolidSection

```{eval-rst}
.. autoclass:: abaqus.Section.CompositeSolidSection.CompositeSolidSection
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ConnectorSection

```{eval-rst}
.. autoclass:: abaqus.Section.ConnectorSection.ConnectorSection
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### EulerianSection

```{eval-rst}
.. autoclass:: abaqus.Section.EulerianSection.EulerianSection
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### GasketSection

```{eval-rst}
.. autoclass:: abaqus.Section.GasketSection.GasketSection
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### GeneralStiffnessSection

```{eval-rst}
.. autoclass:: abaqus.Section.GeneralStiffnessSection.GeneralStiffnessSection
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### GeometryShellSection

```{eval-rst}
.. autoclass:: abaqus.Section.GeometryShellSection.GeometryShellSection
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### HomogeneousShellSection

```{eval-rst}
.. autoclass:: abaqus.Section.HomogeneousShellSection.HomogeneousShellSection
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### HomogeneousSolidSection

```{eval-rst}
.. autoclass:: abaqus.Section.HomogeneousSolidSection.HomogeneousSolidSection
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LayerProperties

```{eval-rst}
.. autoclass:: abaqus.Section.LayerProperties.LayerProperties
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### LayerPropertiesArray

```{eval-rst}
.. autoclass:: abaqus.Section.LayerPropertiesArray.LayerPropertiesArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### MembraneSection

```{eval-rst}
.. autoclass:: abaqus.Section.MembraneSection.MembraneSection
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### MPCSection

```{eval-rst}
.. autoclass:: abaqus.Section.MPCSection.MPCSection
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### PEGSection

```{eval-rst}
.. autoclass:: abaqus.Section.PEGSection.PEGSection
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### RebarLayers

```{eval-rst}
.. autoclass:: abaqus.Section.RebarLayers.RebarLayers
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SectionLayer

```{eval-rst}
.. autoclass:: abaqus.Section.SectionLayer.SectionLayer
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SectionLayerArray

```{eval-rst}
.. autoclass:: abaqus.Section.SectionLayerArray.SectionLayerArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ShellSection

```{eval-rst}
.. autoclass:: abaqus.Section.ShellSection.ShellSection
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SolidSection

```{eval-rst}
.. autoclass:: abaqus.Section.SolidSection.SolidSection
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SurfaceSection

```{eval-rst}
.. autoclass:: abaqus.Section.SurfaceSection.SurfaceSection
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### TransverseShearBeam

```{eval-rst}
.. autoclass:: abaqus.Section.TransverseShearBeam.TransverseShearBeam
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### TransverseShearShell

```{eval-rst}
.. autoclass:: abaqus.Section.TransverseShearShell.TransverseShearShell
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### TrussSection

```{eval-rst}
.. autoclass:: abaqus.Section.TrussSection.TrussSection
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```
